@@ -43,7 +43,7 @@ sub meta_merge {
 	},
 	resources	=> {
 	    bugtracker	=> {
-		web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-satpass',
+		web	=> 'https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues',
                 mailto  => 'wyant@cpan.org',
 	    },
 	    license	=> 'http://dev.perl.org/licenses/',
@@ -73,7 +73,6 @@ sub requires {
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
-	'Astro::Coord::ECI::Sun'	=> 0.091,
 	'Astro::Coord::ECI::TLE'	=> 0.091,
 	'Astro::Coord::ECI::Utils'	=> 0.091,
 	'Carp'		=> 0,
@@ -205,7 +204,8 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues>,
+or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -213,7 +213,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2018 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
